@@ -94,8 +94,8 @@ def test_run_help(cli_runner):
         ["run", "--help"],
     )
 
-    assert result.exit_code == 0
-    assert "djcodemod list" in result.output
+    assert result.exit_code == 1
+    assert "Automatically fixes deprecations" in result.output
 
 
 @pytest.mark.parametrize(
@@ -198,19 +198,21 @@ class NoDocString:
 
 
 class EmptyDocString:
-    """"""
+    """"""  # noqa D419
 
     pass
 
 
 class SingleLine:
-    """This is the description."""
+    """The description."""
 
 
 class MultiLine1:
-    """This is the title.
+    """
+    Some title.
 
-    This is more details."""
+    This is more details.
+    """
 
 
 class MultiLine2:
@@ -226,8 +228,8 @@ class MultiLine2:
     [
         (NoDocString, ""),
         (EmptyDocString, ""),
-        (SingleLine, "This is the description."),
-        (MultiLine1, "This is the title."),
+        (SingleLine, "The description."),
+        (MultiLine1, "Some title."),
         (MultiLine2, "Another title."),
     ],
 )
