@@ -1,5 +1,3 @@
-from typing import Type
-
 from libcst.codemod import CodemodTest
 
 from django_codemod.commands import BaseCodemodCommand
@@ -9,7 +7,7 @@ from django_codemod.visitors.base import BaseDjCodemodTransformer
 class BaseVisitorTest(CodemodTest):
     """Base test to use in all visitors tests."""
 
-    transformer: Type[BaseDjCodemodTransformer]
+    transformer: type[BaseDjCodemodTransformer]
 
     def TRANSFORM(self, context):
         """Create a command for the transformer under test."""
